use strict;
use Test::More tests => 4;
BEGIN { use_ok('Acme::POE::Acronym::Generator'); };
my $poegen = Acme::POE::Acronym::Generator->new( dict => 'words' );
isa_ok( $poegen, 'Acme::POE::Acronym::Generator' );
my $string = $poegen->generate();
ok( $string, $string );
my @list = $poegen->generate();
ok( scalar @list == 3, join ' ', @list );
